==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/V1FlexPersistentVolumeSourceFluentImpl.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.kubernetes.client.fluent.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public class V1FlexPersistentVolumeSourceFluentImpl<A extends V1FlexPersistentVolumeSourceFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements V1FlexPersistentVolumeSourceFluent<A>{

    private String driver;
    private String fsType;
    private Map<String,String> options;
    private Boolean readOnly;
    private V1SecretReferenceBuilder secretRef;

    public V1FlexPersistentVolumeSourceFluentImpl(){
    }
    public V1FlexPersistentVolumeSourceFluentImpl(V1FlexPersistentVolumeSource instance){
            this.withDriver(instance.getDriver());

            this.withFsType(instance.getFsType());

            this.withOptions(instance.getOptions());

            this.withReadOnly(instance.isReadOnly());

            this.withSecretRef(instance.getSecretRef());

    }

    public String getDriver(){
            return this.driver;
    }

    public A withDriver(String driver){
            this.driver=driver; return (A) this;
    }

    public Boolean hasDriver(){
            return this.driver != null;
    }

    public String getFsType(){
            return this.fsType;
    }

    public A withFsType(String fsType){
            this.fsType=fsType; return (A) this;
    }

    public Boolean hasFsType(){
            return this.fsType != null;
    }

    public A addToOptions(String key,String value){
            if(this.options == null && key != null && value != null) { this.options = new LinkedHashMap<String,String>(); }
            if(key != null && value != null) {this.options.put(key, value);} return (A)this;
    }

    public A addToOptions(Map<String,String> map){
            if(this.options == null && map != null) { this.options = new LinkedHashMap<String,String>(); }
            if(map != null) { this.options.putAll(map);} return (A)this;
    }

    public A removeFromOptions(String key){
            if(this.options == null) { return (A) this; }
            if(key != null && this.options != null) {this.options.remove(key);} return (A)this;
    }

    public A removeFromOptions(Map<String,String> map){
            if(this.options == null) { return (A) this; }
            if(map != null) { for(Object key : map.keySet()) {if (this.options != null){this.options.remove(key);}}} return (A)this;
    }

    public Map<String,String> getOptions(){
            return this.options;
    }

    public A withOptions(Map<String,String> options){
            if (options == null) { this.options =  null;} else {this.options = new LinkedHashMap<String,String>(options);} return (A) this;
    }

    public Boolean hasOptions(){
            return this.options != null;
    }

    public Boolean isReadOnly(){
            return this.readOnly;
    }

    public A withReadOnly(Boolean readOnly){
            this.readOnly=readOnly; return (A) this;
    }

    public Boolean hasReadOnly(){
            return this.readOnly != null;
    }

    public A withNewReadOnly(boolean arg1){
            return (A)withReadOnly(new Boolean(arg1));
    }

    public A withNewReadOnly(String arg1){
            return (A)withReadOnly(new Boolean(arg1));
    }

    
/**
 * This method has been deprecated, please use method buildSecretRef instead.
 * @return The buildable object.
 */
@Deprecated public V1SecretReference getSecretRef(){
            return this.secretRef!=null?this.secretRef.build():null;
    }

    public V1SecretReference buildSecretRef(){
            return this.secretRef!=null?this.secretRef.build():null;
    }

    public A withSecretRef(V1SecretReference secretRef){
            _visitables.remove(this.secretRef);
            if (secretRef!=null){ this.secretRef= new V1SecretReferenceBuilder(secretRef); _visitables.add(this.secretRef);} return (A) this;
    }

    public Boolean hasSecretRef(){
            return this.secretRef != null;
    }

    public V1FlexPersistentVolumeSourceFluent.SecretRefNested<A> withNewSecretRef(){
            return new SecretRefNestedImpl();
    }

    public V1FlexPersistentVolumeSourceFluent.SecretRefNested<A> withNewSecretRefLike(V1SecretReference item){
            return new SecretRefNestedImpl(item);
    }

    public V1FlexPersistentVolumeSourceFluent.SecretRefNested<A> editSecretRef(){
            return withNewSecretRefLike(getSecretRef());
    }

    public V1FlexPersistentVolumeSourceFluent.SecretRefNested<A> editOrNewSecretRef(){
            return withNewSecretRefLike(getSecretRef() != null ? getSecretRef(): new V1SecretReferenceBuilder().build());
    }

    public V1FlexPersistentVolumeSourceFluent.SecretRefNested<A> editOrNewSecretRefLike(V1SecretReference item){
            return withNewSecretRefLike(getSecretRef() != null ? getSecretRef(): item);
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V1FlexPersistentVolumeSourceFluentImpl that = (V1FlexPersistentVolumeSourceFluentImpl) o;
            if (driver != null ? !driver.equals(that.driver) :that.driver != null) return false;
            if (fsType != null ? !fsType.equals(that.fsType) :that.fsType != null) return false;
            if (options != null ? !options.equals(that.options) :that.options != null) return false;
            if (readOnly != null ? !readOnly.equals(that.readOnly) :that.readOnly != null) return false;
            if (secretRef != null ? !secretRef.equals(that.secretRef) :that.secretRef != null) return false;
            return true;
    }


    public class SecretRefNestedImpl<N> extends V1SecretReferenceFluentImpl<V1FlexPersistentVolumeSourceFluent.SecretRefNested<N>> implements V1FlexPersistentVolumeSourceFluent.SecretRefNested<N>,io.kubernetes.client.fluent.Nested<N>{

            private final V1SecretReferenceBuilder builder;
    
            SecretRefNestedImpl(V1SecretReference item){
                    this.builder = new V1SecretReferenceBuilder(this, item);
            }
            SecretRefNestedImpl(){
                    this.builder = new V1SecretReferenceBuilder(this);
            }
    
    public N and(){
            return (N) V1FlexPersistentVolumeSourceFluentImpl.this.withSecretRef(builder.build());
    }
    public N endSecretRef(){
            return and();
    }

}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1FlexPersistentVolumeSourceFluentImpl.java <==
package io.kubernetes.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import io.kubernetes.client.fluent.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public class V1FlexPersistentVolumeSourceFluentImpl<A extends V1FlexPersistentVolumeSourceFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements V1FlexPersistentVolumeSourceFluent<A>{

    private String driver;
    private String fsType;
    private Map<String,String> options;
    private Boolean readOnly;
    private V1SecretReferenceBuilder secretRef;

    public V1FlexPersistentVolumeSourceFluentImpl(){
    }
    public V1FlexPersistentVolumeSourceFluentImpl(V1FlexPersistentVolumeSource instance){
            this.withDriver(instance.getDriver());

            this.withFsType(instance.getFsType());

            this.withOptions(instance.getOptions());

            this.withReadOnly(instance.isReadOnly());

            this.withSecretRef(instance.getSecretRef());

    }

    public String getDriver(){
            return this.driver;
    }

    public A withDriver(String driver){
            this.driver=driver; return (A) this;
    }

    public Boolean hasDriver(){
            return this.driver != null;
    }

    public A withNewDriver(String arg1){
            return (A)withDriver(new String(arg1));
    }

    public A withNewDriver(StringBuilder arg1){
            return (A)withDriver(new String(arg1));
    }

    public A withNewDriver(StringBuffer arg1){
            return (A)withDriver(new String(arg1));
    }

    public String getFsType(){
            return this.fsType;
    }

    public A withFsType(String fsType){
            this.fsType=fsType; return (A) this;
    }

    public Boolean hasFsType(){
            return this.fsType != null;
    }

    public A withNewFsType(String arg1){
            return (A)withFsType(new String(arg1));
    }

    public A withNewFsType(StringBuilder arg1){
            return (A)withFsType(new String(arg1));
    }

    public A withNewFsType(StringBuffer arg1){
            return (A)withFsType(new String(arg1));
    }

    public A addToOptions(String key,String value){
            if(this.options == null && key != null && value != null) { this.options = new LinkedHashMap<String,String>(); }
            if(key != null && value != null) {this.options.put(key, value);} return (A)this;
    }

    public A addToOptions(Map<String,String> map){
            if(this.options == null && map != null) { this.options = new LinkedHashMap<String,String>(); }
            if(map != null) { this.options.putAll(map);} return (A)this;
    }

    public A removeFromOptions(String key){
            if(this.options == null) { return (A) this; }
            if(key != null && this.options != null) {this.options.remove(key);} return (A)this;
    }

    public A removeFromOptions(Map<String,String> map){
            if(this.options == null) { return (A) this; }
            if(map != null) { for(Object key : map.keySet()) {if (this.options != null){this.options.remove(key);}}} return (A)this;
    }

    public Map<String,String> getOptions(){
            return this.options;
    }

    public A withOptions(Map<String,String> options){
            if (options == null) { this.options =  null;} else {this.options = new LinkedHashMap<String,String>(options);} return (A) this;
    }

    public Boolean hasOptions(){
            return this.options != null;
    }

    public Boolean isReadOnly(){
            return this.readOnly;
    }

    public A withReadOnly(Boolean readOnly){
            this.readOnly=readOnly; return (A) this;
    }

    public Boolean hasReadOnly(){
            return this.readOnly != null;
    }

    public A withNewReadOnly(String arg1){
            return (A)withReadOnly(new Boolean(arg1));
    }

    public A withNewReadOnly(boolean arg1){
            return (A)withReadOnly(new Boolean(arg1));
    }

    
/**
 * This method has been deprecated, please use method buildSecretRef instead.
 * @return The buildable object.
 */
@Deprecated public V1SecretReference getSecretRef(){
            return this.secretRef!=null?this.secretRef.build():null;
    }

    public V1SecretReference buildSecretRef(){
            return this.secretRef!=null?this.secretRef.build():null;
    }

    public A withSecretRef(V1SecretReference secretRef){
            _visitables.get("secretRef").remove(this.secretRef);
            if (secretRef!=null){ this.secretRef= new V1SecretReferenceBuilder(secretRef); _visitables.get("secretRef").add(this.secretRef);} return (A) this;
    }

    public Boolean hasSecretRef(){
            return this.secretRef != null;
    }

    public V1FlexPersistentVolumeSourceFluent.SecretRefNested<A> withNewSecretRef(){
            return new SecretRefNestedImpl();
    }

    public V1FlexPersistentVolumeSourceFluent.SecretRefNested<A> withNewSecretRefLike(V1SecretReference item){
            return new SecretRefNestedImpl(item);
    }

    public V1FlexPersistentVolumeSourceFluent.SecretRefNested<A> editSecretRef(){
            return withNewSecretRefLike(getSecretRef());
    }

    public V1FlexPersistentVolumeSourceFluent.SecretRefNested<A> editOrNewSecretRef(){
            return withNewSecretRefLike(getSecretRef() != null ? getSecretRef(): new V1SecretReferenceBuilder().build());
    }

    public V1FlexPersistentVolumeSourceFluent.SecretRefNested<A> editOrNewSecretRefLike(V1SecretReference item){
            return withNewSecretRefLike(getSecretRef() != null ? getSecretRef(): item);
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V1FlexPersistentVolumeSourceFluentImpl that = (V1FlexPersistentVolumeSourceFluentImpl) o;
            if (driver != null ? !driver.equals(that.driver) :that.driver != null) return false;
            if (fsType != null ? !fsType.equals(that.fsType) :that.fsType != null) return false;
            if (options != null ? !options.equals(that.options) :that.options != null) return false;
            if (readOnly != null ? !readOnly.equals(that.readOnly) :that.readOnly != null) return false;
            if (secretRef != null ? !secretRef.equals(that.secretRef) :that.secretRef != null) return false;
            return true;
    }


    public class SecretRefNestedImpl<N> extends V1SecretReferenceFluentImpl<V1FlexPersistentVolumeSourceFluent.SecretRefNested<N>> implements V1FlexPersistentVolumeSourceFluent.SecretRefNested<N>,io.kubernetes.client.fluent.Nested<N>{

            private final V1SecretReferenceBuilder builder;
    
            SecretRefNestedImpl(V1SecretReference item){
                    this.builder = new V1SecretReferenceBuilder(this, item);
            }
            SecretRefNestedImpl(){
                    this.builder = new V1SecretReferenceBuilder(this);
            }
    
    public N and(){
            return (N) V1FlexPersistentVolumeSourceFluentImpl.this.withSecretRef(builder.build());
    }
    public N endSecretRef(){
            return and();
    }

}


}
